# clld-cognacy-plugin

[![Build Status](https://travis-ci.org/clld/clld-cognacy-plugin.svg?branch=master)](https://travis-ci.org/clld/clld-cognacy-plugin)
[![codecov](https://codecov.io/gh/clld/clld-cognacy-plugin/branch/master/graph/badge.svg)](https://codecov.io/gh/clld/clld-cognacy-plugin)
[![PyPI](https://img.shields.io/pypi/v/clld-cognacy-plugin.svg)](https://pypi.python.org/pypi/clld-cognacy-plugin)


clld plugin providing functionality for lexical data with cognacy judgements
